==> voreen-src-4.1.1-win.zip: voreen-src-4.1.1-win/modules/base/io/analyzevolumereader.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2012 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_ANALYZEVOLUMEREADER_H
#define VRN_ANALYZEVOLUMEREADER_H

#include "voreen/core/io/volumereader.h"

namespace voreen {

class AnalyzeVolumeReader : public VolumeReader {
public:
    AnalyzeVolumeReader(ProgressBar* progress = 0);
    virtual VolumeReader* create(ProgressBar* progress = 0) const;

    virtual std::string getClassName() const   { return "AnalyzeVolumeReader"; }
    virtual std::string getFormatDescription() const { return "Analyze format"; }

    static std::string getRelatedImgFileName(const std::string& fileName);

    virtual VolumeBase* read(const VolumeURL& origin)
        throw (tgt::FileException, std::bad_alloc);

    virtual VolumeCollection* read(const std::string& url)
        throw (tgt::FileException, std::bad_alloc);

    std::vector<VolumeURL> listVolumes(const std::string& url) const
        throw (tgt::FileException);

private:
    VolumeCollection* read(const std::string& url, int volId)
        throw (tgt::FileException, std::bad_alloc);

    ///@param volId -1: read all, else: read volume volId
    virtual VolumeCollection* readAnalyze(const std::string& fileName, int volId)
        throw (tgt::FileException, std::bad_alloc);

    ///@param volId -1: read all, else: read volume volId
    virtual VolumeCollection* readNifti(const std::string& fileName, bool standalone, int volId)
        throw (tgt::FileException, std::bad_alloc);

    static const std::string loggerCat_;
};

} // namespace voreen

#endif // VRN_ANALYZEVOLUMEREADER_H

==> voreen-src-4.2.1-win.zip: voreen-src-4.2.1-win/modules/base/io/analyzevolumereader.h <==
/***********************************************************************************
 *                                                                                 *
 * Voreen - The Volume Rendering Engine                                            *
 *                                                                                 *
 * Copyright (C) 2005-2013 University of Muenster, Germany.                        *
 * Visualization and Computer Graphics Group <http://viscg.uni-muenster.de>        *
 * For a list of authors please refer to the file "CREDITS.txt".                   *
 *                                                                                 *
 * This file is part of the Voreen software package. Voreen is free software:      *
 * you can redistribute it and/or modify it under the terms of the GNU General     *
 * Public License version 2 as published by the Free Software Foundation.          *
 *                                                                                 *
 * Voreen is distributed in the hope that it will be useful, but WITHOUT ANY       *
 * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR   *
 * A PARTICULAR PURPOSE. See the GNU General Public License for more details.      *
 *                                                                                 *
 * You should have received a copy of the GNU General Public License in the file   *
 * "LICENSE.txt" along with this file. If not, see <http://www.gnu.org/licenses/>. *
 *                                                                                 *
 * For non-commercial academic use see the license exception specified in the file *
 * "LICENSE-academic.txt". To get information about commercial licensing please    *
 * contact the authors.                                                            *
 *                                                                                 *
 ***********************************************************************************/

#ifndef VRN_ANALYZEVOLUMEREADER_H
#define VRN_ANALYZEVOLUMEREADER_H

#include "voreen/core/io/volumereader.h"

namespace voreen {

class VRN_CORE_API AnalyzeVolumeReader : public VolumeReader {
public:
    AnalyzeVolumeReader(ProgressBar* progress = 0);
    virtual VolumeReader* create(ProgressBar* progress = 0) const;

    virtual std::string getClassName() const   { return "AnalyzeVolumeReader"; }
    virtual std::string getFormatDescription() const { return "Analyze format"; }

    static std::string getRelatedImgFileName(const std::string& fileName);

    virtual VolumeBase* read(const VolumeURL& origin)
        throw (tgt::FileException, std::bad_alloc);

    virtual VolumeList* read(const std::string& url)
        throw (tgt::FileException, std::bad_alloc);

    std::vector<VolumeURL> listVolumes(const std::string& url) const
        throw (tgt::FileException);

private:
    VolumeList* read(const std::string& url, int volId)
        throw (tgt::FileException, std::bad_alloc);

    ///@param volId -1: read all, else: read volume volId
    virtual VolumeList* readAnalyze(const std::string& fileName, int volId)
        throw (tgt::FileException, std::bad_alloc);

    ///@param volId -1: read all, else: read volume volId
    virtual VolumeList* readNifti(const std::string& fileName, bool standalone, int volId)
        throw (tgt::FileException, std::bad_alloc);

    static const std::string loggerCat_;
};

} // namespace voreen

#endif // VRN_ANALYZEVOLUMEREADER_H
